summaryrefslogtreecommitdiff
path: root/lib/Target/Sparc/SparcSubtarget.cpp
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2006-02-05 05:50:24 +0000
committerChris Lattner <sabre@nondot.org>2006-02-05 05:50:24 +0000
commit7c90f73a1b06040d971a3dd95a491031ae6238d5 (patch)
treeb08b13069e8e41b83636b53103804110e993d376 /lib/Target/Sparc/SparcSubtarget.cpp
parent213845367cb394237cbf10ccfba5a219bbec4781 (diff)
downloadllvm-7c90f73a1b06040d971a3dd95a491031ae6238d5.tar.gz
llvm-7c90f73a1b06040d971a3dd95a491031ae6238d5.tar.bz2
llvm-7c90f73a1b06040d971a3dd95a491031ae6238d5.tar.xz
Rename SPARC V8 target to be the LLVM SPARC target.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@25985 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/Sparc/SparcSubtarget.cpp')
-rw-r--r--lib/Target/Sparc/SparcSubtarget.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/Target/Sparc/SparcSubtarget.cpp b/lib/Target/Sparc/SparcSubtarget.cpp
index 46ea7d4284..beda79d49b 100644
--- a/lib/Target/Sparc/SparcSubtarget.cpp
+++ b/lib/Target/Sparc/SparcSubtarget.cpp
@@ -1,4 +1,4 @@
//===- SparcV8Subtarget.cpp - SPARC Subtarget Information -----------------===//
//
// The LLVM Compiler Infrastructure
//
@@ -11,8 +11,8 @@
//
//===----------------------------------------------------------------------===//
-#include "SparcV8Subtarget.h"
-#include "SparcV8GenSubtarget.inc"
+#include "SparcSubtarget.h"
+#include "SparcGenSubtarget.inc"
using namespace llvm;
// FIXME: temporary.
@@ -22,7 +22,7 @@ namespace {
cl::desc("Enable V9 instructions in the V8 target"));
}
-SparcV8Subtarget::SparcV8Subtarget(const Module &M, const std::string &FS) {
+SparcSubtarget::SparcSubtarget(const Module &M, const std::string &FS) {
// Set the default features.
IsV9 = false;
V8DeprecatedInsts = false;
@@ -1,4 +1,4 @@
-//===- SparcV8Subtarget.cpp - SPARC Subtarget Information -----------------===//
+//===- SparcSubtarget.cpp - SPARC Subtarget Information -------------------===//
//
// The LLVM Compiler Infrastructure